@@ -4,6 +4,7 @@ import git
 from shutil import move
 from .printing import *
 from .config import get_config
+from .utils import safe_mkdir
 
 #########
 # GLOBALS
@@ -13,7 +14,7 @@ COMMIT_MSG = {
 	"fonts": "Back up fonts.",
 	"packages": "Back up packages.",
 	"configs": "Back up configs.",
-	"all": "Full back up.",
+	"full_backup": "Full back up.",
 	"dotfiles": "Back up dotfiles."
 }
 
@@ -44,6 +45,7 @@ def create_gitignore(dir_path, key):
 	Handles backwards compatibility for the default-gitignore -> root-gitignore
 	change and the introduction of the dotfiles-gitignore key in v4.0.
 	"""
+	safe_mkdir(dir_path)
 	gitignore_path = os.path.join(dir_path, ".gitignore")
 	print_yellow_bold(f"Updating .gitignore file at {gitignore_path} with config from {key}")
 	try:
@@ -52,7 +54,7 @@ def create_gitignore(dir_path, key):
 		if key == "root-gitignore":
 			files_to_ignore = get_config()["default-gitignore"]
 		elif key == "dotfiles-gitignore":
-			pass
+			files_to_ignore = []
 	with open(os.path.join(dir_path, ".gitignore"), "w+") as f:
 		for ignore in files_to_ignore:
 			f.write("{}\n".format(ignore))
